@@ -380,11 +380,12 @@
 	  last
 	  posq
 	  posv
-	  position
+	  posqual
 	  reduce
 	  sublist
 	  insert
 	  unspecific
+	  symbol-append
 
 	  (mvlet :syntax)))
 
@@ -1030,6 +1031,7 @@
 	  scan-forms
 	  expand-scanned-form
 	  syntax?
+	  static-value
 	  make-compiler-env
 	  bind-source-file-name))
 
@@ -1059,6 +1061,32 @@
 	  operator-uid
 	  operator?
 	  operators-table		;config.scm comp-package.scm
+
+	  lambda-node?
+	  flat-lambda-node?
+	  name-node?
+	  call-node?
+	  literal-node?
+	  quote-node?
+	  define-node?
+	  loophole-node?
+
+	  operator/flat-lambda
+	  operator/lambda
+	  operator/set!
+	  operator/call
+	  operator/begin
+	  operator/name
+	  operator/letrec
+	  operator/pure-letrec
+	  operator/literal
+	  operator/quote
+	  operator/unassigned
+	  operator/unspecific
+	  operator/define
+	  operator/define-syntax
+	  operator/primitive-procedure
+	  operator/structure-ref
 	  ))
 
 ;----------------
@@ -1114,6 +1142,7 @@
 	  template-offset
 	  environment-offset
 	  depth-check!
+	  index->offset
 	  literal->index
 	  binding->index))
 
@@ -1197,8 +1226,7 @@
 	  make-new-location		;ctop.scm
 	  structure-package
 	  note-structure-name!
-	  (:package :type)
-	  (:structure :type)))		;for (define-method ...)'s
+	  (:package :type)))
 
 (define-interface packages-internal-interface
   (export package-loaded?		;env/load-package.scm
