@@ -1,4 +1,4 @@
-; Copyright (c) 1993-2005 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Copyright (c) 1993-2007 by Richard Kelsey and Jonathan Rees. See file COPYING.
 
 
 ; Proposals are four-element vectors.  There doesn't seem to be much point
@@ -107,6 +107,8 @@
 	       (set-proposal-in-use?! proposal true))
 	   (set-current-proposal! proposal)
 	   (goto return unspecific-value))
+	  ((vm-eq? proposal (current-proposal))
+	   (goto return unspecific-value))
 	  (else
 	   (raise-exception wrong-type-argument 0 proposal)))))
 
@@ -397,7 +399,7 @@
 ;----------------
 ; Mostly error-checking as usual.
 
-(define-primitive copy-bytes! (any-> fixnum-> any-> fixnum-> fixnum->)
+(define-primitive copy-bytes! (code-vector-> fixnum-> code-vector-> fixnum-> fixnum->)
   (lambda (from from-index to to-index count)
     (let ((lose (lambda ()
 		  (raise-exception wrong-type-argument 1
@@ -405,8 +407,8 @@
 				   to (enter-fixnum to-index)
 				   (enter-fixnum count))))
 	  (no-log? (= 0 (code-byte 0))))
-      (cond ((not (and (okay-copy-args? from from-index count)
-		       (okay-copy-args? to   to-index   count)
+      (cond ((not (and (okay-copy-code-vector? from from-index count)
+		       (okay-copy-code-vector? to   to-index   count)
 		       (not (immutable? to))
 		       (<= 0 count)))
 	     (lose))
@@ -438,19 +440,10 @@
 	(loop (- left (copy-count copies))
 	      (copy-next copies)))))
 
-; THING must be a string or code-vector with 0 <= INDEX and
-; (INDEX + COUNT) <= the length of THING.
-
-(define (okay-copy-args? thing index count)
+(define (okay-copy-code-vector? c index count)
   (and (<= 0 index)
-       (cond ((vm-string? thing)
-	      (<= (+ index count)
-		  (vm-string-length thing)))
-	     ((code-vector? thing)
-	      (<= (+ index count)
-		  (code-vector-length thing)))
-	     (else
-	      #f))))
+       (<= (+ index count)
+	   (code-vector-length c))))
 
 ;----------------
 ; Committing a proposal.
